Zetor7011 = {};

function Zetor7011.prerequisitesPresent(specializations)
	return true;
end;

function Zetor7011:load(xmlFile)
	
    -- Revers lights initializaiton
    self.reverseLightObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.reverse#index"));
    setVisibility(self.reverseLightObject, false);
    self.reverseLightActive = false;
    
    -- Brake lights initializaiton
    self.brakeLightObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.brake#index"));
    setVisibility(self.brakeLightObject, false);
    self.brakeLightActive = false;
    
    -- Turn lights
    self.leftTurnObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.leftTurn#index"))
    setVisibility(self.leftTurnObject, false);
    self.leftTurnActive = false;
    self.flashLeft = false;
    
    self.rightTurnObject = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.utilLights.rightTurn#index"))
    setVisibility(self.rightTurnObject, false);
    self.rightTurnActive = false;
    self.flashRight = false;
    
    self.flash = false;
    self.flashWarn = false;
    self.timer = 10;

	self.backupMinRpm = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#minRpm"), 1000);
	local motorMaxRpmStr = getXMLString(xmlFile, "vehicle.motor#maxRpm");
    local motorMaxRpm1, motorMaxRpm2, motorMaxRpm3 = Utils.getVectorFromString(motorMaxRpmStr);
    motorMaxRpm1 = Utils.getNoNil(motorMaxRpm1, 800);
    motorMaxRpm2 = Utils.getNoNil(motorMaxRpm2, 1000);
    motorMaxRpm3 = Utils.getNoNil(motorMaxRpm3, 1800);
	self.fieldMode = true;
	self.backUpBrakeForce = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#brakeForce"), 10)*2;
	self.backUpBackwardGearRatio = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motor#backwardGearRatio"), 1.5);
	self.backUpMaxRpm = motorMaxRpm3;
	self.temp = 25;
	self.coolingOn = false;
	self.coolingTemp = 0;
	self.tempOnBord = true;
		
	local numWorkLights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.worklights#count"), 0);
    self.worklights = {};
    for i=1, numWorkLights do
        local worklightnamei = string.format("vehicle.worklights.worklight%d", i);
        self.worklights[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, worklightnamei .. "#index"));
        setVisibility(self.worklights[i], false);
    end;
	self.warmUp = 0.025;
	self.isStarted = false;
	
	self.helpPanelPath = Utils.getFilename("textures/Zetor7011HUD.png", self.baseDirectory);
	self.HudWidth = 0.386;
	self.HudHeight = 0.252; --old 0.256;
	self.HudPosX = 0.001;
	self.HudPosY = 0.001;
	self.helpPanelTextPosX = 0.002;
	self.helpPanelTextPosY = 0.356;
	self.helpPanelOverlay = Overlay:new("Helppanel", self.helpPanelPath, self.HudPosX, self.HudPoxY, self.HudWidth, self.HudHeight);
	self.helpPanelActive = false;

end;

function Zetor7011:delete()
end;

function Zetor7011:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Zetor7011:keyEvent(unicode, sym, modifier, isDown)
    if InputBinding.isPressed(InputBinding.LEVA) then
        if not self.flashLeft or self.flashWarn then
            self.flashLeft = false;
        end;
        self.flashLeft = not self.flashLeft;
        self.flashRight = false;
        self.flashWarn = false;
        self.timer = 10;
    end;
    if InputBinding.isPressed(InputBinding.PRAVA) then
        if not self.flashRight or self.flashWarn then
            self.flashRight = false;
        end;
        self.flashRight = not self.flashRight;
        self.flashLeft = false;
        self.flashWarn = false;
        self.timer = 10;
    end;
    if InputBinding.isPressed(InputBinding.VYSTRAZNA) then
        if self.flashWarn then
            self.flashLeft = false;
            self.flashRight = false;
        else
            self.rightTurnActive = false;
            self.leftTurnActive = false;
            self.flashLeft = true;
            self.flashRight = true;
        end;
        self.flashWarn = not self.flashWarn;
        self.timer = 10;
    end;
end;

function Zetor7011:stopMotor()
    self.motor.minRpm = self.backupMinRpm;
end;

function Zetor7011:update(dt)
	
    -- Reverse lights
    if self.movingDirection < 0 then
        self.reverseLightActive = true;
    else
        self.reverseLightActive = false;
    end;
    setVisibility(self.reverseLightObject, self.reverseLightActive);
    
    -- Brake lights
    setVisibility(self.brakeLightObject, self.brakeLightActive);
    
    if (self.movingDirection*self.lastSpeed*(-self.input)) < -0.001 then
        self.brakeLightActive = true;
    else
        self.brakeLightActive = false;
    end;
    
	-- Turn lights
    if self.flashLeft or self.flashRight then
        self.timer = self.timer - dt;
        if self.flashRight or self.flashWarn then
            if self.timer < 0 then
                self.rightTurnActive = not self.rightTurnActive;
            end;
        else
            self.rightTurnActive = false;
        end;
    
        if self.flashLeft or self.flashWarn then
            if self.timer < 0 then
                self.leftTurnActive = not self.leftTurnActive;
            end;
        else
            self.leftTurnActive = false;
        end;
        if self.timer < 0 then
            self.timer = 500;
        end;
    else
        self.rightTurnActive = false;
        self.leftTurnActive = false;
    end;
    setVisibility(self.rightTurnObject, self.rightTurnActive);
    setVisibility(self.leftTurnObject, self.leftTurnActive);
	
	if self.isEntered then
		if InputBinding.hasEvent(InputBinding.Zetor7011) then
			self.helpPanelActive = not self.helpPanelActive;
		end;
	end;
		
	self.input = InputBinding.getAnalogInputAxis(InputBinding.AXIS_FORWARD);
	if InputBinding.isAxisZero(self.input) then
		self.input = InputBinding.getDigitalInputAxis(InputBinding.AXIS_FORWARD);
	end;
	
	local maxRpm = self.motor:getMaxRpm();
	local torque = self.motor.torqueCurve:get(self.motor.lastMotorRpm);
	if self.input ~= 0 or self.motor.speedLevel ~= 0 then
		local differenz = maxRpm-self.motor.lastMotorRpm;
		if differenz <= 510 then
			self.motor.minRpm = self.motor.minRpm+(differenz/50);
		else
			self.motor.minRpm = self.motor.minRpm-(differenz/40);
		end;
		if self.motor.minRpm <= -650 then
			self.motor.minRpm = -650;
		elseif self.motor.minRpm >= 1100 then
			self.motor.minRpm = 1100;
		end;
		if self.fieldMode then
			self.motor.minRpm = (self.motor.minRpm-120);
		else
			self.motor.minRpm = self.motor.minRpm;
		end;
	end;
	
	if self.motor.lastMotorRpm > 0 then
		self.isStarted = true;
	else
		self.isStarted = false;
	end;
	
	if self.tempOnBord then
		if self.isStarted then
			local maxRpm = self.motor:getMaxRpm();
			local powerDifferenz = ((100/self.motor.lastMotorRpm)*maxRpm)-100;
			local lastMotorRpm = self.motor.lastMotorRpm;
			if powerDifferenz > 100 then
				powerDifferenz = 100;
			elseif powerDifferenz < 0 then
				powerDifferenz = 0;
			end;
			if maxRpm < self.motor.minRpm then
				maxRpm = self.motor.minRpm;
			end;
			if self.input == 0 or self.motor.speedLevel == 0 then
				if self.temp < 80 then
					self.temp = self.temp+(4/lastMotorRpm);
				else
					self.temp = self.temp-(2/lastMotorRpm);
				end;
			end;
			if powerDifferenz > 0 then
				self.temp = self.temp+(powerDifferenz/6000);
			end;
			if self.temp > 87 then
				self.coolingOn = true;
			end;
			if self.coolingOn == true and self.temp < 81 then
				self.coolingOn = false;
			end;
			if self.coolingOn == true then
				self.temp = self.temp-(6/lastMotorRpm);
			end;
		else
			self.temp = self.temp-(self.warmUp/10);
		end;
		if self.temp < 24 then
			self.temp = 24;
		end;
	end;
end;

function Zetor7011:onLeave()
	self.motor.minRpm = self.backupMinRpm;
end;

function Zetor7011:draw()

	if self.helpPanelActive then
		self.helpPanelOverlay:render();
		renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.135, 0.025, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.Zetor7011), g_i18n:getText("7011helpon")));
		if not self.isMotorStarted and not self.automaticStart then	
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.279, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.IGNITION), g_i18n:getText("7011start")));
		else
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.351, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.IGNITION), g_i18n:getText("7011stop")));
		end;
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.255, 0.024, string.format("Taste %s: %s/%s/%s", g_i18n:getText("smerovky"), InputBinding.getButtonKeyName(InputBinding.LEVA), InputBinding.getButtonKeyName(InputBinding.PRAVA),InputBinding.getButtonKeyName(InputBinding.VYSTRAZNA), g_i18n:getText("smerovky")));

		if self.isMotorStarted then	
			if self.motor.speedLevel ~= 0 then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.279, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.PRIDAT), InputBinding.getButtonKeyName(InputBinding.UBRAT), self.motor.maxRpm[self.motor.speedLevel]));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.279, 0.024, string.format("Taste %s/%s: %d RPM", InputBinding.getButtonKeyName(InputBinding.PRIDAT), InputBinding.getButtonKeyName(InputBinding.UBRAT), self.motor.maxRpm[3]));
			end;
			if self.reverse then
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.303, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.TEMPOMAT), g_i18n:getText("7011forward")));
			else
				renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.303, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.TEMPOMAT), g_i18n:getText("7011Backward")));
			end;
		end;
		if self.rundumleuchtenAnz > 0 and self:getIsActive() then
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.327, 0.024, string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.MAJAK), g_i18n:getText("Majak")));
		end;
		if self.tempOnBord then
			local red = 0.0;
			local green = 0.0;
			local blue = 0.0;
			if self.temp < 63 then
				red = 0.0;
				green = 0.0;
				blue = 1.0;
			elseif self.temp >= 63 and self.temp <= 92 then
				blue = 0.0;
				red = 0.0;
				green = 1.0;
			elseif self.temp > 92 then
				red = 1.0;
				green = 0.0;
				blue = 0.0;
			end;
			setTextColor(red, green, blue, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("                          %d 'C", self.temp));
			setTextColor(1.0, 1.0, 1.0, 1.0);
			renderText(self.helpPanelTextPosX, self.helpPanelTextPosY-0.231, 0.024, string.format("Teplota Motoru:"));
		end;
	else
		if not self.isMotorStarted and not self.automaticStart then	
			g_currentMission:addHelpButtonText(g_i18n:getText("7011start"), InputBinding.IGNITION);
		end;
		g_currentMission:addHelpButtonText(g_i18n:getText("7011helpoff"), InputBinding.Zetor7011);
	end;
end;

function Zetor7011:validateAttacherJoint(implement, jointDesc, dt)
    return true;
end;

function Zetor7011:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)

	local loadTemp = getXMLFloat(xmlFile, key.."#temp");
	if loadTemp ~= nil then
		self.temp = loadTemp;
	end;
	return BaseMission.VEHICLE_LOAD_OK;
end;

function Zetor7011:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'temp="'..self.temp..'"';
    return attributes, nil;
end;